set define '^' verify off
prompt ...wwv_flow_data_export_pdf.sql
create or replace package wwv_flow_data_export_pdf as
--------------------------------------------------------------------------------
--
--  Copyright (c) Oracle Corporation 2020 All Rights Reserved.
--
--    NAME
--      wwv_flow_data_export_pdf.sql
--
--    DESCRIPTION
--      This package is responsible for PDF data exports
--
--

--------------------------------------------------------------------------------
-- Global variables
--------------------------------------------------------------------------------
--

--==============================================================================
-- The procedure initializes attributes needed for data export.
--
-- p_pdf_accessible    Include accessibility tags in the PDF
--==============================================================================
procedure init ( 
    p_pdf_accessible    in boolean,
    p_pdf_exact_widths  in boolean );

--==============================================================================
-- The procedure emits top header and necessary logic to emit headings
--==============================================================================
procedure emit_header;

--==============================================================================
-- The procedure emits a new column break
--==============================================================================
procedure emit_column_break;

--==============================================================================
-- The procedure emits a row with highlights if defined.
--==============================================================================
procedure emit_row;

--==============================================================================
-- The procedure emits previous column break aggregate values.
--==============================================================================
procedure emit_aggregates;

--==============================================================================
-- The procedure emits the overall aggregate values.
--==============================================================================
procedure emit_overall;

--==============================================================================
-- The function returns the clob buffer as a blob.
--==============================================================================
function get_blob_output return blob;

--==============================================================================
-- Clears all the memory structures
--==============================================================================
procedure free;

end wwv_flow_data_export_pdf;
/
show errors
