set define '^' verify off
prompt ...sys.wwv_flow_val
col SHARING_CLAUSE noprint new_val SHARING_CLAUSE
select case
       when to_number(regexp_substr(version,'^\d+')) >= 18 then 'sharing=none'
       end SHARING_CLAUSE
  from sys.dba_registry
 where comp_id='CATPROC'
/
create or replace package sys.wwv_flow_val ^SHARING_CLAUSE. authid current_user as
--------------------------------------------------------------------------------
--
-- Copyright (c) 2005 - 2020, Oracle.  All rights reserved.
--
--    NAME
--      wwv_flow_val.sql
--
--    DESCRIPTION
--      Access library SYS.WWV_FLOW_VAL_LIB
--
--    NOTES
--      Hard-coded reference to schema name, e.g., FLOWS_020100 must be
--      maintained for each release. Implementation in kkxhtmldb.c verifies the
--      package name.
--
--    MODIFIED   (MM/DD/YY)
--    lvbcheng    09/06/2005 - Created
--    sspadafo    10/25/2005 - Split into separate spec and body files
--    mhichwa     12/08/2005 - Removed references to product name
--    jkallman    01/23/2006 - Adjust flows_020100 references to flows_020200
--    jkallman    09/29/2006 - Adjust flows_020200 references to flows_030000
--    jkallman    08/02/2007 - Change FLOWS_030000 references to FLOWS_030100
--    jkallman    07/08/2008 - Changed FLOWS_030100 references to FLOWS_040000
--    jkallman    10/02/2008 - Changed FLOWS_040000 references to APEX_040000
--    jkallman    11/22/2010 - Changed APEX_040000 references to APEX_040100
--    pawolf      02/21/2012 - Changed APEX_040100 references to APEX_040200
--    cneumuel    10/15/2012 - Removed well known username and password in doc of verify_user (bug #14760689)
--    jkallman    12/17/2012 - Change APEX_040200 references to APEX_050000
--    cneumuel    11/07/2014 - Added get_version_identifier (feature #1153)
--    msewtz      07/07/2015 - Change APEX_050000 references to APEX_050100
--    cneumuel    09/09/2016 - Moved grant to coreins.sql
--
--------------------------------------------------------------------------------

--
-- Revise this constant as required for new product versions
--
c_apex_schema constant char(11) := 'APEX_210200';

--==============================================================================
-- Return values for verify_user
--==============================================================================

valid_user   constant pls_integer := 0;
invalid_user constant pls_integer := 1;
null_input   constant pls_integer := -1;

--==============================================================================
-- Exceptions for verify_user
--==============================================================================

invalid_caller   exception; -- The user is not allowed to call this package.
internal_error   exception; -- Unusual situations (e.g. out of memory, database
                            -- down).
account_locked   exception; -- The account is locked.
password_expired exception; -- The password has expired.

--==============================================================================
-- exception constants
--==============================================================================

invalid_caller_errcode     constant pls_integer:= -32058;
internal_error_errcode     constant pls_integer:= -600;
account_locked_errcode     constant pls_integer:= -28000;
password_expired_errcode   constant pls_integer:= -28001;

pragma exception_init(invalid_caller,     -32058);
pragma exception_init(internal_error,     -600);
pragma exception_init(account_locked,     -28000);
pragma exception_init(password_expired,   -28001);

--==============================================================================
-- Verify that the username and password pair is valid.
--
-- This package can only be called by the current APEX_nnnnnn schema (product
-- release-specific). Any other caller will be rejected.
--
-- PARAMETERS:
-- * username: Username to be validated. Blank padded usernames are not valid.
--             Thus, 'MYUSER ' is not equal to 'MYUSER'.
-- * password: Password to be validated. Blank padded usernames are not valid.
--             Thus, 'MYPASSWORD ' is not equal to 'MYPASSWORD'.
--==============================================================================
function verify_user (
    username IN varchar2 character set any_cs,
    password IN varchar2 character set any_cs )
    return pls_integer;

--==============================================================================
function authorize_user (
    username  IN varchar2 character set any_cs,
    groupname IN varchar2 character set any_cs)
    return BOOLEAN;

--==============================================================================
function get_version_identifier
    return varchar2;

end wwv_flow_val;
/
show errors

create or replace library sys.wwv_flow_val_lib trusted is static
/
