set define '^' verify off
prompt ...wwv_flow_ws_api
create or replace package wwv_flow_ws_api as
--------------------------------------------------------------------------------
--
--  Copyright (c) Oracle Corporation 2008 - 2021. All Rights Reserved.
--
--    NAME
--      wwv_flow_ws_api.sql
--
--    DESCRIPTION
--      API to manage Websheet applications.
--
--    RUNTIME DEPLOYMENT: YES
--
--    MODIFIED   (MM/DD/YYYY)
--      cbcho     04/17/2008 - Created
--
--------------------------------------------------------------------------------

g_canonical_date_format varchar2(100) := 'RRRR-MM-DD"T"hh24:mi:ss';
g_canonical_ts_format   varchar2(100) := 'RRRR-MM-DD"T"hh24:mi:ss.xff';
g_dml_date_format       varchar2(100) := 'YYYYMMDDHH24MISS';

g_edit_row_collection_name  varchar2(255) := 'APEX$_WS_ROWS_EDIT_ROW';

empty_vc_arr wwv_flow_global.vc_arr2;
type col_val_arr_t is table of varchar2(32767) index by varchar2(32767);
type col_arr is table of col_val_arr_t index by binary_integer;

g_column_change_in_progress  boolean := false;

function get_data_grid_alias (
    p_ws_app_id     in number,
    p_data_grid_id  in number) return varchar2;
    
function get_page_alias (
    p_ws_app_id    in number,
    p_page_id      in number) return varchar2;
    
function ws_error_handling (
    p_error in wwv_flow_error_api.t_error )
    return wwv_flow_error_api.t_error_result;

function is_alphanumeric (
    p_str        in varchar2)
    return boolean;
        
function check_section_lost_update (    
    p_ws_app_id             in number,
    p_page_id               in number,
    p_section_id            in number,
    p_change_count          in number,
    --    
    p_section_type          in varchar2 default null,
    p_display_seq           in number default null,
    p_title                 in varchar2 default null,
    p_content               in varchar2 default null,
    p_nav_start_webpage_id  in number default null,
    p_nav_max_level         in number default null,
    p_nav_order_by          in varchar2 default null,
    p_nav_order_by_dir      in varchar2 default null,
    p_nav_include_link      in varchar2 default null,
    --
    p_clob_item_name        in varchar2 default null,
    --   
    p_data_grid_id          in number default null,
    p_report_id             in number default null,
    p_data_section_style    in number default null,
    --
    p_chart_type            in varchar2 default null,
    p_chart_label           in varchar2 default null,
    p_label_axis_title      in varchar2 default null,
    p_chart_value           in varchar2 default null,
    p_value_axis_title      in varchar2 default null,
    p_chart_aggregate       in varchar2 default null,
    p_chart_sorting         in varchar2 default null,
    p_chart_orientation     in varchar2 default null
    ) return varchar2;    

function get_section_clob ( 
    p_item_name        in varchar2,
    p_section_id       in number default null)
    return clob;
    
function show_reset_password (
    p_ws_app_id    in number)
    return boolean;

function get_home_page_id (
    p_ws_app_id    in number) return number;
        
function is_app_home_page (
    p_ws_app_id    in number,
    p_webpage_id   in number)
    return boolean;
    
function get_logo (
	p_ws_app_id         in number,
	p_security_group_id in number)
	return varchar2;

function get_dbms_sql_cursor(
    p_query  in varchar2,
    p_values in wwv_flow_global.vc_arr2 default empty_vc_arr)
    return integer;

function alias_exists (
    p_ws_app_id    in number,
    p_alias        in varchar2,
    p_alias_type   in varchar2,
    p_worksheet_id in number default null,
    p_page_id      in number default null,
    p_id           in number default null) return boolean;

function annotation_exists (
    p_ws_app_id      in number) return boolean;

function page_annotation_exists (
    p_ws_app_id       in number,
    p_webpage_id      in number,
    p_annotation_type in varchar2) return boolean;

function get_next_webpg_section_seq (
    p_webpage_id       in number)  return number;

function get_utilization_num (
    p_workspace_id     in number default null,
    p_type             in varchar2 default null) return number;
 
function duplicate_found_in_array (    
    p_array in wwv_flow_global.vc_arr2) return boolean;
    
function get_data_grid_id (
    p_worksheet_id     in number) return number;

function get_ws_app_id (
    p_worksheet_id      in number) return number;

function get_websheet_name (
    p_worksheet_id     in number) return varchar2;

function websheet_name_exists (
    p_ws_app_id     in number,
    p_name          in varchar2,
    p_type          in varchar2 default 'DATA',
    p_worksheet_id  in number default null) return boolean;

function get_item_value (
    p_item_name in varchar2
    ) return varchar2;

function max_col_limit_reached (
    p_worksheet_id   in number,
    p_column_type    in varchar2) return boolean;
    
function get_condition_display (
    p_column_name       in varchar2 default null,
    p_column_label      in varchar2 default null,
    p_operator          in varchar2 default null,
    p_expr              in varchar2 default null,
    p_expr2             in varchar2 default null,
    p_condition_display in varchar2 default null) return varchar2;

procedure update_page_timestamp (    
    p_page_id   in number,
    p_ws_app_id in number);
    
procedure run_block (
    p_sql        in varchar2);

function check_plsql (
    p_sql               in varchar2
    ) return varchar2;
        
procedure run_query (
    p_sql        in varchar2,
    p_values     in wwv_flow_global.vc_arr2 default empty_vc_arr,
    p_max_row    in number default null,
    p_col_vals   out col_arr);

procedure remove_ws_app (
    p_ws_app_id in number );

procedure save_checked (
        p_worksheet_id   in number);

procedure delete_rows (
    p_websheet_id      in number,
    p_rows             in varchar2 default 'SELECTED',
    p_selected_rows    in varchar2 default null,
    p_confirm          in varchar2 default null,
    p_validation_error out varchar2);

procedure delete_row (
    p_websheet_id   in number,
    p_row_id        in number);

procedure process_row (
        p_ws_app_id         in  number,
        p_worksheet_id      in  number,
        p_websheet_id       in  number,
        p_row_id            in  number,
        f01                 in  wwv_flow_global.vc_arr2 default empty_vc_arr,
        f02                 in  wwv_flow_global.vc_arr2 default empty_vc_arr,
        p_validation_error  out varchar2,
        p_validation_count  out number,
        p_ajax_mode         in  boolean                 default false );

----------
-- Sharing
--
procedure share_ws_with_individuals (
        p_worksheet_id in number,
        p_person_list in varchar2,
        p_allow_select in varchar2,
        p_allow_insert in varchar2,
        p_allow_update in varchar2,
        p_allow_delete in varchar2);

--
-- inline updates
--
procedure update_cell (
    p_worksheet_id     in number,
    p_websheet_id      in number,
    p_row_id           in number,
    p_column_name      in varchar2,
    p_new_value        in varchar2 default null,
    p_change_count     in number default null,
    p_validation_error out varchar2);

procedure save_websheet_properties (
    p_ws_app_id        in number,
    p_worksheet_id     in number,
    p_name             in varchar2 default null,
    p_alias            in varchar2 default null,
    p_description      in varchar2 default null,
    p_row_pk1          in varchar2 default null,
    p_row_pk2          in varchar2 default null,
    p_row_pk3          in varchar2 default null,
    p_publish          in varchar2 default null,
    p_validation_error out varchar2
    );

procedure save_column_properties (
    p_worksheet_id      in number,
    p_websheet_id       in number,
    p_app_user          in varchar2 default null,
    p_db_column_name    in varchar2 default null,
    p_display_order     in varchar2 default null,
    p_group_id          in number default null,
    p_display_as        in varchar2 default null,
    p_lov_id            in varchar2 default null,
    p_lov_name          in varchar2 default null,
    p_lov_entries       in varchar2 default null,
    p_label             in varchar2 default null,
    p_format_mask       in varchar2 default null,
    p_value_required    in varchar2 default null,
    p_heading_alignment in varchar2 default null,
    p_column_alignment  in varchar2 default null,
    p_default_type      in varchar2 default null,
    p_default_text      in varchar2 default null,
    p_width             in number default null,
    p_max_width         in number default null,
    p_height            in number default null,
    p_help_text         in varchar2 default null,
    p_validation_error  out varchar2
    );

procedure create_ws_column (
    p_id                      in number   default null,
    p_flow_id                 in number   default 4900,
    p_page_id                 in number   default null,
    p_worksheet_id            in number   default null,
    p_websheet_id             in number   default null,
    --
    p_db_column_name          in varchar2 default null,
    p_display_order           in number   default null,
    p_data_grid_form_seq      in number   default null,
    p_group_id                in number   default null,
    p_column_identifier       in varchar2 default null,
    p_column_expr             in varchar2 default null,
    p_column_label            in varchar2 default null,
    p_report_label            in varchar2 default null,
    p_sync_form_label         in varchar2 default 'Y',
    --
    p_display_in_default_rpt  in varchar2 default null,
    p_column_html_expression  in varchar2 default null,
    p_column_link             in varchar2 default null,
    p_column_linktext         in varchar2 default null,
    p_column_link_attr        in varchar2 default null,
    p_column_link_checksum_type in varchar2 default null,
    --
    p_is_sortable             in varchar2 default null,
    p_allow_sorting           in varchar2 default null,
    p_allow_filtering         in varchar2 default null,
    p_allow_highlighting      in varchar2 default null,
    p_allow_ctrl_breaks       in varchar2 default null,
    p_allow_aggregations      in varchar2 default null,
    p_allow_computations      in varchar2 default null,
    p_allow_charting          in varchar2 default null,
    p_allow_group_by          in varchar2 default null,
    p_allow_pivot             in varchar2 default null,
    p_allow_hide              in varchar2 default null,
    --
    p_use_custom              in varchar2 default null,
    p_custom_filter           in varchar2 default null,
    p_base_column             in varchar2 default null,
    p_allow_filters           in varchar2 default null,
    --
    p_others_may_edit         in varchar2 default null,
    p_others_may_view         in varchar2 default null,
    --
    p_column_type             in varchar2 default null,
    p_display_as              in varchar2 default null,
    p_display_text_as         in varchar2 default null,
    p_heading_alignment       in varchar2 default null,
    p_column_alignment        in varchar2 default null,
    p_max_length              in number   default null,
    p_display_width           in number   default null,
    p_display_height          in number   default null,
    --
    p_allow_null              in varchar2 default null,
    p_format_mask             in varchar2 default null,
    p_tz_dependent            in varchar2 default null,
    p_fact_table_key          in varchar2 default null,
    p_dimension_table         in varchar2 default null,
    p_dimension_table_id      in varchar2 default null,
    p_dimension_table_value   in varchar2 default null,
    --
    p_rpt_distinct_lov        in varchar2 default null,
    p_rpt_lov                 in varchar2 default null,
    p_rpt_named_lov           in number   default null,
    p_rpt_show_filter_lov     in varchar2 default null,
    p_rpt_filter_date_ranges  in varchar2 default null,
    --
    p_static_lov              in varchar2 default null,
    p_lov_null_text           in varchar2 default null,
    p_lov_allow_new_values    in varchar2 default null,
    p_lov_is_distinct_values  in varchar2 default null,
    p_lov_num_columns         in number   default null,
    p_lov_id                  in number   default null,
    --
    p_computation_type        in varchar2 default null,
    p_computation_expr_1      in varchar2 default null,
    p_computation_expr_2      in varchar2 default null,
    --
    p_validation_type         in varchar2 default null,
    p_validation_expr_1       in varchar2 default null,
    p_validation_expr_2       in varchar2 default null,
    --
    p_display_condition_type  in varchar2 default null,
    p_display_condition       in varchar2 default null,
    p_display_condition2      in varchar2 default null,
    --
    p_default_value           in varchar2 default null,
    p_default_when            in varchar2 default null,
    p_help_text               in varchar2 default null,
    p_security_scheme         in varchar2 default null,
    p_column_flags            in varchar2 default null,
    p_column_comment          in varchar2 default null );

procedure add_column (
    p_worksheet_id     in number,
    p_websheet_id      in number,
    p_app_user         in varchar2 default null,
    p_report_id        in number default null,
    p_column_name      in varchar2 default null,
    p_group_id         in number default null,
    p_column_type      in varchar2 default null,
    p_display_as       in varchar2 default null,
    p_lov_id           in varchar2 default null,
    p_lov_name         in varchar2 default null,
    p_lov_entries      in varchar2 default null,
    p_value_required   in varchar2 default null,
    p_default_type     in varchar2 default null,
    p_default_text     in varchar2 default null,
    p_validation_error out varchar2
    );

procedure remove_column (
    p_worksheet_id     in number,
    p_columns          in varchar2 default null,
    p_confirm          in varchar2 default null,
    p_validation_error out varchar2
    );

procedure delete_lov (
    p_worksheet_id     in number,
    p_lov_id           in number default null,
    p_validation_error out varchar2
    );

procedure save_lov (
    p_worksheet_id     in number,
    p_websheet_id      in number,
    p_lov_id           in number default null,
    p_lov_name         in varchar2 default null,
    p_lov_entries      in varchar2 default null,
    p_validation_error out varchar2
    );

procedure save_column_group (
    p_worksheet_id     in number,
    p_websheet_id      in number,
    p_group_id         in number default null,
    p_seq              in number default null,
    p_group_name       in varchar2 default null,
    p_description      in varchar2 default null,
    p_columns          in varchar2 default null,
    p_validation_error out varchar2
    );

procedure delete_column_group (
    p_worksheet_id     in number,
    p_group_id         in number);

procedure copy_page (
    p_ws_app_id        in number,
    p_webpage_id       in number,
    p_new_name         in varchar2 default null,
    --
    p_new_page_id      out number);
    
procedure copy_websheet (
    p_ws_app_id        in number,
    p_worksheet_id     in number,
    p_websheet_id      in number,   
    p_new_name         in varchar2 default null,
    p_validation_error out varchar2
    );

procedure delete_websheet (
    p_worksheet_id     in number,
    p_websheet_id      in number,
    p_websheet_type    in varchar2 default 'DATA',
    p_confirm          in varchar2 default null,
    p_validation_error out varchar2);

procedure set_column_value (
    p_websheet_id      in number,
    p_db_column_name   in varchar2 default null,
    p_new_value        in varchar2 default null,
    p_rows             in varchar2 default 'SELECTED',
    p_selected_rows    in varchar2 default null,
    p_validation_error out varchar2);

procedure replace_column_value (
    p_websheet_id       in number,
    p_rows              in varchar2 default null,
    p_db_column_names   in varchar2 default null,
    p_find_what         in varchar2 default null,
    p_replace_with      in varchar2 default null,
    p_selected_rows     in varchar2 default null,
    p_validation_error  out varchar2);

procedure fill_column_value (
    p_websheet_id        in number,
    p_db_column_name     in varchar2 default null,
    p_validation_error   out varchar2);

procedure add_note (
    p_ws_app_id        in number default null,
    p_note_id          in number default null,
    p_websheet_id      in number default null,
    p_row_id           in number default null,
    p_webpage_id       in number default null,
    p_component_level  in varchar2 default null,
    p_content          in varchar2 default null);
    
procedure add_note (
    p_ws_app_id        in number default null,
    p_note_id          in number default null,
    p_websheet_id      in number default null,
    p_row_id           in number default null,
    p_webpage_id       in number default null,
    p_component_level  in varchar2 default null,
    p_content          in varchar2 default null,
    -- out
    p_validation_error out varchar2);

procedure add_link (
    p_link_id          in number default null,
    p_ws_app_id        in number default null,
    p_websheet_id      in number default null,
    p_row_id           in number default null,
    p_component_level  in varchar2 default null,
    p_link_name        in varchar2 default null,
    p_url              in varchar2 default null,
    p_link_description in varchar2 default null,
    p_display_sequence in number default null,
    p_validation_error out varchar2);

procedure add_tags (
    p_ws_app_id       in number default null,
    p_webpage_id      in number default null,
    p_websheet_id     in number default null,
    p_row_id          in number default null,
    p_component_level in varchar2 default null,
    p_tag             in varchar2 default null);

procedure add_acl_entry (
    p_ws_app_id       in number default null,
    p_acl_id          in number default null,
    p_username        in varchar2 default null,
    p_priv            in varchar2 default null);

procedure delete_note (
    p_note_id   in number);

procedure delete_link (
    p_link_id in number);

procedure delete_tag (
    p_tag_id         in number,
    p_websheet_id    in number default null,
    p_row_id         in number default null
    );

procedure delete_acl_entry (
    p_acl_id         in number);

procedure get_websheet_attr (
    p_worksheet_id        in number,
    p_app_user            in varchar2 default null,
    p_base_report_id      in number default null,
    p_status              out varchar2,
    p_view_only_columns   out varchar2,
    p_username_in_columns out varchar2,
    p_parent_column       out varchar2,
    p_child_column        out varchar2);

procedure save_column_validation (
    p_ws_app_id        in number,
    p_worksheet_id     in number,
    p_websheet_id      in number default null,
    p_validation_id    in number default null,
    p_validation_level in varchar2 default null,
    p_name             in varchar2 default null,
    p_seq              in number default null,
    p_type             in varchar2 default null,
    p_expr1            in varchar2 default null,
    p_expr2            in varchar2 default null,
    p_error_message    in varchar2 default null,
    p_validation_error out varchar2
    );

procedure delete_column_validation (
    p_worksheet_id     in number,
    p_validation_id    in number default null
    );

procedure change_column_type (
    p_worksheet_id         in number,
    p_websheet_id          in number,
    p_old_db_column_name   in varchar2,
    p_new_column_type      in varchar2,
    p_format_mask_to_use   in varchar2 default null);

procedure create_history_collection (
    p_worksheet_id  in number,
    p_websheet_id   in number,
    p_max_row_count in number default null
    );

procedure create_link_collection (
    p_ws_app_id    in number,
    p_max_row_count in number default null
    );

procedure get_link_info (
    p_ws_app_id       in number,
    p_id              in number,
    p_component_level out varchar2,
    p_webpage_id      out number,
    p_worksheet_id    out number,
    p_websheet_id     out number,
    p_row_id          out number,
    p_link_name       out varchar2,
    p_url             out varchar2,      
    p_created_on      out date,
    p_created_by      out varchar2,
    p_updated_on      out date,
    p_updated_by      out varchar2
    );
    
procedure create_acl_collection (
    p_ws_app_id     in number,
    p_max_row_count in number default null
    );

procedure create_attachment_collection (
    p_ws_app_id     in number,
    p_max_row_count in number default null
    );

procedure create_sec_history_collection (
    p_ws_app_id     in number,
    p_webpage_id    in number default null,
    p_max_row_count in number default null
    );

procedure create_search_collection (
    p_search                in varchar2 default null,
    p_security_group_id     in number   default null,
    p_ws_app_id             in number   default null,
    p_max_row_count         in number   default null,
    p_searchable_components in varchar2 default null,
    p_app_session           in varchar2 default '0'
    );

procedure create_pg_sec_collection (
    p_security_group_id     in number   default null,
    p_ws_app_id             in number   default null,
    p_page_id               in number   default null,
    p_app_session           in varchar2 default '0'
    );

procedure create_section_collection (
    p_security_group_id     in number   default null,
    p_ws_app_id             in number   default null,
    p_page_id               in number   default null
    );

procedure get_attachment_info (
    p_ws_app_id        in number,
    p_id               in number,
    p_component_level  out varchar2,
    p_webpage_id       out number,
    p_worksheet_id     out number,
    p_websheet_id      out number,
    p_row_id           out number,
    p_name             out varchar2,
    p_image_alias      out varchar2,
    p_image_attributes out varchar2,
    p_description      out varchar2,
    p_created_on       out date,
    p_created_by       out varchar2,
    p_updated_on       out date,
    p_updated_by       out varchar2
    );

procedure create_note_collection (
    p_ws_app_id     in number,
    p_max_row_count in number default null
    );

procedure get_note_info (
    p_ws_app_id       in number,
    p_id              in number,
    p_component_level out varchar2,
    p_webpage_id      out number,
    p_worksheet_id    out number,
    p_websheet_id     out number,
    p_row_id          out number,
    p_note            out varchar2,
    p_created_on      out date,
    p_created_by      out varchar2,
    p_updated_on      out date,
    p_updated_by      out varchar2
    );

procedure create_tag_collection (
    p_ws_app_id     in number,
    p_max_row_count in number default null
    );

procedure get_tag_info (
    p_ws_app_id       in number,
    p_id              in number,
    p_component_level out varchar2,
    p_webpage_id      out number,
    p_worksheet_id    out number,
    p_websheet_id     out number,
    p_row_id          out number,
    p_tag             out varchar2,
    p_created_on      out date,
    p_created_by      out varchar2,
    p_updated_on      out date,
    p_updated_by      out varchar2
    );

procedure create_webpage (
    p_webpage_id      in number default null,
    p_ws_app_id       in number default null,
    p_name            in varchar2 default null,
    p_page_alias      in varchar2 default null,
    p_description     in varchar2 default null,
    p_parent_page_id  in number default null,
    p_section_title   in varchar2 default null,
    p_section_content in varchar2 default null);

procedure fetch_note (
    p_note_id     in  number,
    -- out
    p_content     out varchar2);

procedure fetch_tag (
    p_webpage_id  in number,
    --
    p_tags        out varchar2);

procedure fetch_data_section (
    p_section_id           in number,
    p_section_type         in varchar2,
    -- out
    p_display_seq          out number,
    p_title                out varchar2,
    --
    p_worksheet_id         out number,
    p_websheet_type        out varchar2,
    p_websheet_id          out number,
    p_websheet_name        out varchar2,
    p_report_id            out number,
    p_data_section_style   out number,
    p_change_count         out number,
    p_max_row_count        out number,
    p_show_option          out varchar2
    );

procedure fetch_chart_section (
    p_section_id           in number,
    p_section_type         in varchar2,
    -- out
    p_display_seq          out number,
    p_title                out varchar2,
    --
    p_worksheet_id         out number,
    p_websheet_type        out varchar2,
    p_websheet_id          out number,
    p_websheet_name        out varchar2,
    p_report_id            out number,
    p_report_columns       out varchar2,
    --
    p_chart_type           out varchar2,
    p_chart_label          out varchar2,
    p_label_axis_title     out varchar2,
    p_chart_value          out varchar2,
    p_value_axis_title     out varchar2,
    p_chart_aggregate      out varchar2,
    p_chart_sorting        out varchar2,
    p_chart_orientation    out varchar2,
    p_change_count         out number
    );

procedure fetch_section_info (
    p_section_id       in number,
    -- out
    p_display_seq      out number,
    p_title            out varchar2,
    p_change_count     out number
    );

function fetch_section_content (
    p_section_id       in number    
    ) return clob;    

procedure fetch_nav_section (
    p_section_id           in number,
    p_section_type         in varchar2,
    -- out
    p_display_seq          out number,
    p_title                out varchar2,
    p_nav_start_webpage_id out number,
    p_nav_max_level        out number,
    p_nav_order_by         out varchar2,
    p_nav_order_by_dir     out varchar2,
    p_nav_include_link     out varchar2,
    p_change_count         out number);

procedure save_webpage_section (
    p_section_id            in number default null,
    p_ws_app_id             in number default null,
    p_webpage_id            in number default null,
    p_section_type          in varchar2 default null,
    p_display_seq           in number default null,
    p_title                 in varchar2 default null,
    p_content               in varchar2 default null,
    p_nav_start_webpage_id  in number default null,
    p_nav_max_level         in number default null,
    p_nav_order_by          in varchar2 default null,
    p_nav_order_by_dir      in varchar2 default null,
    p_nav_include_link      in varchar2 default null,
    --
    p_clob_item_name        in varchar2 default null,
    --
    p_data_grid_id          in number default null,
    p_report_id             in number default null,
    p_data_section_style    in number default null,
    p_max_row_count         in number default null,
    p_show_option           in varchar2 default null,
    --
    p_chart_type            in varchar2 default null,
    p_chart_label           in varchar2 default null,
    p_label_axis_title      in varchar2 default null,
    p_chart_value           in varchar2 default null,
    p_value_axis_title      in varchar2 default null,
    p_chart_aggregate       in varchar2 default null,
    p_chart_sorting         in varchar2 default null,
    p_chart_orientation     in varchar2 default null
    );

procedure save_section_seq_title (
    p_section_id            in number default null, 
    p_ws_app_id             in number default null,
    p_webpage_id            in number default null,    
    p_display_seq           in number default null,
    p_title                 in varchar2 default null    
    );
    
procedure delete_webpage_section (
    p_section_id       in number default null,
    p_section_type     in varchar2 default null,
    p_ws_app_id        in number default null,
    p_webpage_id       in number default null);

procedure move_section_to_new_page (
    p_ws_app_id             in number,
    p_section_id            in number,
    p_old_page_id           in number,
    p_new_page_name         in varchar2,
    p_new_page_alias        in varchar2 default null,
    p_new_parent_page_id    in number default null,
    p_new_section_sequence  in number default null
    );

procedure move_section_to_existing_page (
    p_ws_app_id             in number,
    p_section_id            in number,
    p_old_page_id           in number,
    p_new_page_id           in number,
    p_new_section_sequence  in number default null
    );

procedure display_create_ws_app_confirm(
    p_ws_app_id      in number,
    p_name           in varchar2,
    p_description    in varchar2 default null,
    p_section_title  in varchar2 default null
    );

function admin_exists (
    p_ws_app_id   in number) return boolean;
    
procedure create_acl_user (
    p_ws_app_id     in number,
    p_method        in varchar2 default null,
    p_username      in varchar2 default null,
    p_email         in varchar2 default null,
    p_password      in varchar2 default null
    );

procedure add_ws_page (
    p_page_type       in varchar2,
    p_page_name       in varchar2,
    p_parent_page_id  in number default null,
    p_ws_report_owner in varchar2 default null,
    p_ws_report_table in varchar2 default null);

procedure delete_webpage (
    p_ws_app_id   in number,
    p_webpage_id  in number);

procedure delete_ws_app (
    p_ws_app_id   in number);

procedure create_ws_report (
    p_report_id    in  number   default null,
    p_ws_app_id    in  number   default null,
    p_flow_id      in  number   default null,
    p_schema       in  varchar2 default null,
    p_source_type  in  varchar2 default null,
    p_report_name  in  varchar2 default null,
    p_report_alias in  varchar2 default null,
    p_table_name   in  varchar2 default null,
    p_query        in  varchar2 default null,
    p_worksheet_id out number,
    p_websheet_id  out number);

procedure split_ws_rpt_link_url (
    p_url               in varchar2,
    --
    p_websheet_id       out number,
    p_reset_ir          out varchar2,
    p_clear_ir          out varchar2,
    p_column1           out varchar2,
    p_operator1         out varchar2,
    p_value1            out varchar2,
    p_column2           out varchar2,
    p_operator2         out varchar2,
    p_value2            out varchar2,
    p_column3           out varchar2,
    p_operator3         out varchar2,
    p_value3            out varchar2
    );

function build_ws_rpt_link_url (
    p_ws_app_id         in number,
    p_websheet_id       in number,
    p_reset_ir          in varchar2 default null,
    p_clear_ir          in varchar2 default null,
    p_column1           in varchar2 default null,
    p_operator1         in varchar2 default null,
    p_value1            in varchar2 default null,
    p_column2           in varchar2 default null,
    p_operator2         in varchar2 default null,
    p_value2            in varchar2 default null,
    p_column3           in varchar2 default null,
    p_operator3         in varchar2 default null,
    p_value3            in varchar2 default null
    ) return varchar2;

procedure edit_ws_report_attr (
    p_worksheet_id              in number,
    p_websheet_id               in number,
    p_websheet_name             in varchar2,
    p_websheet_alias            in varchar2,
    p_max_row_count             in number default null,
    p_max_row_count_message     in varchar2 default null,
    p_no_data_found_message     in varchar2 default null,
    p_base_pk1                  in varchar2 default null,
    p_show_nulls_as             in varchar2 default null,
    p_pagination_type           in varchar2 default null,
    p_show_detail_link          in varchar2 default null,
    p_detail_link               in varchar2 default null,
    p_detail_link_text          in varchar2 default null,
    p_detail_link_attr          in varchar2 default null,
    p_allow_exclude_null_values in varchar2 default null,
    p_allow_hide_extra_columns  in varchar2 default null
    );

procedure edit_ws_rpt_column_attr (
    p_worksheet_id           in number,
    p_column_id              in number,
    p_display_text_as        in varchar2 default null,
    p_column_label           in varchar2 default null,
    p_report_label           in varchar2 default null,
    p_sync_form_label        in varchar2 default null,
    p_format_mask            in varchar2 default null,
    p_heading_alignment      in varchar2 default null,
    p_column_alignment       in varchar2 default null,
    p_allow_sorting          in varchar2 default null,
    p_allow_filtering        in varchar2 default null,
    p_allow_ctrl_breaks      in varchar2 default null,
    p_allow_aggregations     in varchar2 default null,
    p_allow_computations     in varchar2 default null,
    p_allow_charting         in varchar2 default null,
    p_allow_group_by         in varchar2 default null,
    p_allow_pivot            in varchar2 default null,
    p_allow_hide             in varchar2 default null,
    p_allow_filters          in varchar2 default null,
    p_allow_highlighting     in varchar2 default null,
    p_rpt_show_filter_lov    in varchar2 default null,
    p_rpt_lov                in varchar2 default null,
    p_column_link            in varchar2 default null,
    p_column_linktext        in varchar2 default null,
    p_column_link_attr       in varchar2 default null);

function ws_rpt_src_changed (
    p_worksheet_id    in number,
    p_websheet_id     in number,
    p_new_owner       in varchar2,
    p_new_source      in varchar2
    ) return boolean;

procedure change_ws_rpt_query (
    p_worksheet_id    in number,
    p_websheet_id     in number,
    p_new_owner       in varchar2,
    p_new_source      in varchar2 default null
    );

procedure save_ws_rpt_query (
    p_flow_id        in number,
    p_worksheet_id   in number,
    p_websheet_id    in number,
    p_owner          in varchar2 default null,
    p_query          in varchar2 default null
    );

function get_item_help (
    p_db_column_name    in varchar2,
    p_workspace_id      in number,
    p_worksheet_id      in number
    ) return varchar2;

procedure get_ws_report_attr (
    p_websheet_id  in number,
    p_name         out varchar2,
    p_alias        out varchar2);

function inline_date_picker_options(
    p_worksheet_id      in varchar,
    p_date              in varchar,
    p_column            in varchar )
return varchar2;

function get_section_name (
	p_section_id   in number)
	return varchar2
	;

function get_page_count (
    p_ws_app_id    in number)
    return number;
    
function get_report_count (
    p_ws_app_id    in number)
    return number;
    
function get_datagrid_count (
    p_ws_app_id    in number)
    return number;
    
function get_file_count (
	p_ws_app_id    in number)
	return number
	;
function get_file_size (
	p_ws_app_id   in number)
	return number
	;

function get_section_count (
	p_ws_app_id   in number)
	return number;

function get_note_count (
	p_ws_app_id   in number)
	return number;

function get_tag_count (
	p_ws_app_id   in number)
	return number;
	
function get_datagrid_row_count (
	p_ws_app_id   in number)
	return number;

function get_acl_table 
    return clob;

procedure send_page_email (
    p_ws_app_id   in number,
    p_webpage_id  in number,
    p_to          in varchar2 default null,
    p_subject     in varchar2 default null,
    p_body        in varchar2 default null
    );

procedure create_data_grid_from_cp_paste (
    p_app_id            in number,
    p_ws_app_id         in number,
    p_name              in varchar2,
    p_alias             in varchar2 default null,
    p_headings_included in varchar2 default null,
    p_collection_name   in varchar2 default null,
    p_worksheet_id      out number,
    p_websheet_id       out number
    );
        
procedure create_data_grid_from_scratch (
    p_ws_app_id     in number,
    p_name          in varchar2,
    p_alias         in varchar2 default null,
    p_column_order  in varchar2 default null,
    p_worksheet_id  out number,
    p_websheet_id   out number
    );

procedure p33_fetch_blob_format (
    p_format_mask         in varchar2,
    --
    p_type                out varchar2,
    p_blob_table          out varchar2,
    p_blob_column         out varchar2,
    p_pk1_column          out varchar2,
    p_pk2_column          out varchar2,
    p_mimetype_column     out varchar2,
    p_filename_column     out varchar2,
    p_last_upd_column     out varchar2,
    p_charset_column      out varchar2,
    p_content_disposition out varchar2,
    p_download_text       out varchar2
    );

procedure get_lov_json(
    p_worksheet_id   in varchar2,
    p_db_column_name in varchar2 default null
    );              
    
    
end  wwv_flow_ws_api;
/
show errors
