/*!
 *
 * Require JS configuration for JET
 * Copyright (c) 1999, 2021, Oracle and/or its affiliates. All rights reserved.
 *
 */
/**
 * Require.js configuration
 */
( function( $, debug ) {
    "use strict";

    var dbg = !!$v( "pdebug" );

    requirejs.config({

        // Path mappings for the logical module names
        baseUrl: apex_img_dir + "libraries/",
        paths: {
            "ojs":                  "./oraclejet/11.0.0/js/libs/oj/v11.0.0/" + ( dbg ? "debug" : "min" ),
            "ojL10n":               "./oraclejet/11.0.0/js/libs/oj/v11.0.0/ojL10n",
            "ojtranslations":       "./oraclejet/11.0.0/js/libs/oj/v11.0.0/resources",
            "knockout":             "./oraclejet/11.0.0/js/libs/knockout/knockout-3.5.1",
            "knockout-mapping":     "./oraclejet/11.0.0/js/libs/knockout/knockout.mapping-latest",
            "jquery":               "./jquery/3.6.0/jquery-3.6.0.min",
            "jqueryui-amd":         "./oraclejet/11.0.0/js/libs/jquery/jqueryui-amd-1.12.1.min",
            "text":                 "./oraclejet/11.0.0/js/libs/require/text",
            "hammerjs":             "./hammer/2.0.8/hammer-2.0.8.min",
            "signals":              "./oraclejet/11.0.0/js/libs/js-signals/signals.min",
            "ojdnd":                "./oraclejet/11.0.0/js/libs/dnd-polyfill/dnd-polyfill-1.0.2.min",
            "css":                  "./oraclejet/11.0.0/js/libs/require-css/css.min",
            "css-builder":          "./oraclejet/11.0.0/js/libs/require-css/css-builder",
            "normalize":            "./oraclejet/11.0.0/js/libs/require-css/normalize",
            "preact":               "./oraclejet/11.0.0/js/libs/preact/dist/preact.umd",
            "proj4":                "./oraclejet/11.0.0/js/libs/proj4js/dist/proj4",
            "touchr":               "./oraclejet/11.0.0/js/libs/touchr/touchr"
        },

        // Shim configurations for modules that do not expose AMD
        shim: {
            "jquery": {
                exports: [ "jQuery", "$" ]
            }
        },

        // This section configures the i18n plugin. It is merging the Oracle JET built-in translation
        // resources with a custom translation file.
        // Any resource file added, must be placed under a directory named "nls". You can use a path mapping or you can define
        // a path that is relative to the location of this main.js file.
        config: {
            ojL10n: {
                merge: {
                    //"ojtranslations/nls/ojtranslations": "./oraclejet/3.0.0/js/libs/oj/v3.0.0/resources/nls/myTranslations"
                }
            },
            text: {
                // Override for the requirejs text plugin XHR call for loading text resources on CORS configured servers
                // eslint-disable-next-line no-unused-vars
                useXhr: function (url, protocol, hostname, port) {
                    // Override function for determining if XHR should be used.
                    // url: the URL being requested
                    // protocol: protocol of page text.js is running on
                    // hostname: hostname of page text.js is running on
                    // port: port of page text.js is running on
                    // Use protocol, hostname, and port to compare against the url being requested.
                    // Return true or false. true means "use xhr", false means "fetch the .js version of this resource".
                    return true;
                }
            }
        }
    });

})( apex.jQuery, apex.debug );